#Data Analysis for "Using Respiration Quotients to Track Changing Sources of Soil Respiration Seasonally and with Experimental Warming"
#Caitlin Hicks Pries, Alon Angert, Cristina Castanha, Boaz Hilman, Margaret Torn

library(plyr)
library(MASS)
library(reshape2)
library(car) 
library(ggplot2)
library(nlme)
library(bbmle)
library(doBy)
library(rootSolve) 
library(splines)
library(gtable)
library(grid)
library(lubridate)
library(piecewiseSEM)

sterr = function(x) sqrt(var(x,na.rm=TRUE)/length(na.omit(x)))

#####read in GW data CO2 and 13C data
setwd("~/Desktop/LBL Postdoc/Data/Gas Well Data/Production Calcs")
data=read.csv("ARQ_13C_data.csv", header=TRUE)
str(data)
data$Date=strptime(data$Date, "%m/%d/%y") 
data$Datect=as.POSIXct(data$Date)
data$Depthf=as.factor(as.numeric(data$Depth))

####Graphing and Analyzing ARQ####

dataARQ_sum<-data[complete.cases(data[ , 7]),]

#data summary by season
dataARQ_sum$season=revalue(dataARQ_sum$YMo, c("2015 7"="summer", "2016 2"="winter", "2016 4"="summer",
                                "2016 8"="summer", "2017 3"="winter", "2017 6"="summer"))

datasumS=ddply(dataARQ_sum[,-2], c("season"), summarise,
               m=mean(ARQ.m, na.rm=TRUE),
               sd=sd(ARQ.m, na.rm=TRUE),
               n=sum(!is.na(ARQ.m)), #length would also work if no NA's
               se=sd/sqrt(n))

#data summary by depth
datasumD=ddply(dataARQ_sum[,-2], c("Depth"), summarise,
               m=mean(ARQ.m, na.rm=TRUE),
               sd=sd(ARQ.m, na.rm=TRUE),
               n=sum(!is.na(ARQ.m)), #length would also work if no NA's
               se=sd/sqrt(n))

#statistical analyses

#potential variables (some already exist but rename to match model nomenclature below)
dataARQ_sum$Datef=as.factor(dataARQ_sum$YMo)
dataARQ_sum$Mo=1 + as.POSIXlt(dataARQ_sum$Date)$mon 
dataARQ_sum$Mo=as.factor(as.numeric(dataARQ_sum$Mo))

####Analyze ARQ for each depth separately####

dataARQ_30=subset(dataARQ_sum, Depthf=="30")
dataARQ_90=subset(dataARQ_sum, Depthf=="90")

#model for 30 cm
M0=lm(ARQ.m~Datef*Treatment, data=dataARQ_30)

summary(M0)

#check assumptions graphically
plot(M0, select=c(1)) 
hist(M0$residuals, freq=FALSE) 

F=fitted(M0)
R=residuals(M0)

N=!is.na(dataARQ_30$ARQ.m)
Rfull=vector(length=length(dataARQ_30$ARQ.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~dataARQ_30$Datef)
boxplot(Rfull~dataARQ_30$Plot)
boxplot(Rfull~dataARQ_30$UID)
par(op)

#basic model to compare random effects to
M1=gls(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit)
summary(M1)

##test for optimal random effects, random intercept model
M1a=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|Plot, method="REML")
M1b=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="REML")

anova(M1, M1a, M1b) #M1 has lowest AIC but it is repeated measures design, so use M1b

#test for correlation structure
cs1 <- corARMA(form = ~ Datect |UID, p = 1, q = 0) 
cs2 <- corARMA(form = ~ Datect |UID, p = 0, q = 2) 
M1b1=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit,
        random=~1|UID, method="REML") 
M1b2=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit,
        random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
M1b3=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="REML", correlation = cs1)
M1b4=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="REML", correlation = cs2)
anova(M1b1, M1b2, M1b3, M1b4)  #M1b1 best, no correlation structure needed

M1b=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="ML")
summary(M1b)
M1b_a=lme(ARQ.m~Datef+Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="ML")
anova(M1b, M1b_a) #M1b is better, p=0.025, needs interaction term
summary(M1b_a)
M1b_b=lme(ARQ.m~Datef, data=dataARQ_30, na.action=na.omit, 
          random=~1|UID, method="ML")
anova(M1b, M1b_b) #p=0.0067, need Treatment term
M1b_b=lme(ARQ.m~Treatment, data=dataARQ_30, na.action=na.omit, 
          random=~1|UID, method="ML")
anova(M1b, M1b_b) #p<0.0001 need Datef term

M1b=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="REML")
summary(M1b)
anova(M1b)

#check assumptions graphically
hist(M1b$residuals, freq=FALSE) 

F=fitted(M1b)
R=residuals(M1b)

N=!is.na(dataARQ_30$ARQ.m)
Rfull=vector(length=length(dataARQ_30$ARQ.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~dataARQ_30$Datef)
boxplot(Rfull~dataARQ_30$Plot)
boxplot(Rfull~dataARQ_30$UID)
par(op)


#model for 90 cm
dataARQ_30=dataARQ_90 #called 30 so didn't have to rewrite code below.

M0=lm(ARQ.m~Datef*Treatment, data=dataARQ_30)

summary(M0)

#check assumptions graphically
plot(M0, select=c(1)) 
hist(M0$residuals, freq=FALSE) 

F=fitted(M0)
R=residuals(M0)

N=!is.na(dataARQ_30$ARQ.m)
Rfull=vector(length=length(dataARQ_30$ARQ.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~dataARQ_30$Datef)
boxplot(Rfull~dataARQ_30$Plot)
boxplot(Rfull~dataARQ_30$UID)
par(op)

#basic model to compare random effects to
M1=gls(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit)
summary(M1)

##test for optimal random effects, random intercept model
M1a=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|Plot, method="REML")

M1b=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="REML")

anova(M1, M1a, M1b) #M1 has lowest AIC but it is repeated measures design, so use M1b

#test for correlation structure
cs1 <- corARMA(form = ~ Datect |UID, p = 1, q = 0) 
cs2 <- corARMA(form = ~ Datect |UID, p = 0, q = 2) 
M1b1=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit,
         random=~1|UID, method="REML") 
M1b2=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit,
         random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
M1b3=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
         random=~1|UID, method="REML", correlation = cs1)
M1b4=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
         random=~1|UID, method="REML", correlation = cs2)
anova(M1b1, M1b2, M1b3, M1b4)  #M1b1 best, no correlation structure needed

M1b=lme(ARQ.m~Datef*Treatment, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="ML")
summary(M1b)
M1b_a=lme(ARQ.m~Datef+Treatment, data=dataARQ_30, na.action=na.omit, 
          random=~1|UID, method="ML") 
anova(M1b, M1b_a) #p=0.657, no interaction needed
summary(M1b_a)
M1b_b=lme(ARQ.m~Datef, data=dataARQ_30, na.action=na.omit, 
          random=~1|UID, method="ML")
anova(M1b_a, M1b_b) #p=0.4081, do not need Treatment term
summary(M1b_b)
M1b_d=lme(ARQ.m~1, data=dataARQ_30, na.action=na.omit, 
          random=~1|UID, method="ML")
anova(M1b_b, M1b_d) #p<0.0001 need Datef term

M1b_b=lme(ARQ.m~Datef, data=dataARQ_30, na.action=na.omit, 
        random=~1|UID, method="REML")
summary(M1b_b)
anova(M1b_b)

#check assumptions graphically
hist(M1b_b$residuals, freq=FALSE) 

F=fitted(M1b_b)
R=residuals(M1b_b)

N=!is.na(dataARQ_30$ARQ.m)
Rfull=vector(length=length(dataARQ_30$ARQ.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~dataARQ_30$Datef)
boxplot(Rfull~dataARQ_30$Plot)
boxplot(Rfull~dataARQ_30$UID)
par(op)

####end model ARQ separately for each depth

####Analyze ARQ all depths with first date left out (missing 30 cm samples)####
data_alldepths=subset(dataARQ_sum, Date>"2015-08-01") 

cs1 <- corARMA(form = ~ Datect |UID, p = 1, q = 0) #what I could get to converge
cs2 <- corARMA(form = ~ Datect |UID, p = 0, q = 2) #what I could get to converge
M1a=lme(ARQ.m~YMo*Treatment*Depthf, data=data_alldepths, na.action=na.omit,
        random=~1|UID, method="REML") #start here because repeated measures on the same wells
M1b=lme(ARQ.m~YMo*Treatment*Depthf, data=data_alldepths, na.action=na.omit,
        random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
M1c=lme(ARQ.m~YMo*Treatment*Depthf, data=data_alldepths, na.action=na.omit, 
         random=~1|UID, method="REML", correlation = cs1)
M1d=lme(ARQ.m~YMo*Treatment*Depthf, data=data_alldepths, na.action=na.omit, 
        random=~1|UID, method="REML", correlation = cs2)
anova(M1a, M1b, M1c, M1d)  #M1a best, no correlation structure needed

M1a=lme(ARQ.m~YMo*Treatment*Depthf, data=data_alldepths, na.action=na.omit,
        random=~1|UID, method="ML")
summary(M1a)
M1aa=lme(ARQ.m~YMo+Treatment+Depthf+YMo*Treatment+Treatment*Depthf+YMo*Depthf, data=data_alldepths, na.action=na.omit,
        random=~1|UID, method="ML") #remove 3 way interaction
anova(M1a, M1aa) #Drop 3 way interaction, p=0.5279
summary(M1aa)
M1ab=lme(ARQ.m~YMo+Treatment+Depthf+YMo*Treatment+YMo*Depthf, data=data_alldepths, na.action=na.omit,
         random=~1|UID, method="ML")
anova(M1aa, M1ab)#Drop TxD interaction, p=0.1318
summary(M1ab)
M1ac=lme(ARQ.m~YMo+Treatment+Depthf+YMo*Depthf, data=data_alldepths, na.action=na.omit,
         random=~1|UID, method="ML")
anova(M1ab, M1ac) #Drop YMoxT interaction, p=0.3239
summary(M1ac) 
M1ad=lme(ARQ.m~YMo+Depthf+YMo:Depthf, data=data_alldepths, na.action=na.omit,
         random=~1|UID, method="ML")
anova(M1ac, M1ad) #Drop Treatment,p=0.1888
summary(M1ad)
M1ae=lme(ARQ.m~YMo+Depthf, data=data_alldepths, na.action=na.omit,
         random=~1|UID, method="ML")
anova(M1ad, M1ae) 
summary(M1ae) #Keep Depthf x YMo interaction, thus keep main effects 

Mfinal=lme(ARQ.m~YMo*Depthf, data=data_alldepths, na.action=na.omit,
         random=~1|UID, method="REML")
summary(Mfinal)

#check assumptions graphically
hist(Mfinal$residuals, freq=FALSE) 

F=fitted(Mfinal)
R=residuals(Mfinal)

N=!is.na(data_alldepths$ARQ.m)
Rfull=vector(length=length(data_alldepths$ARQ.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~data_alldepths$Datef)
boxplot(Rfull~data_alldepths$Plot)
boxplot(Rfull~data_alldepths$UID)
boxplot(Rfull~data_alldepths$Treatment)
par(op)

#library(MASS)
#fmod<-stepAIC(M1a)
#summary(fmod) #agrees with above but leaves Treatment:Depth and thus Treatment, even though no sig dif in AIC in keeping it

####


####ARQ graphs for paper####
#ARQ v Time by Treatment and Depth
tmp=dataARQ_sum$Date
dataARQ_sum$Date = as.character(dataARQ_sum$Date)
datasum=ddply(dataARQ_sum, c("Treatment", "Depth", "Date"), summarise,
              m=mean(ARQ.m, na.rm=TRUE),
              sd=sd(ARQ.m, na.rm=TRUE),
              n=sum(!is.na(ARQ.m)), #length would also work if no NA's
              se=sd/sqrt(n))
dataARQ_sum$Date = tmp
datasum$Date=as.Date(datasum$Date, "%Y-%m-%d")
datasum$Depth.f=as.factor(datasum$Depth)


#ARQ by depth and treatment 
#Figure 2A
dataARQ_sum$DateD=as.Date(dataARQ_sum$Date, "%Y-%m-%d")
ARQalt=ggplot(dataARQ_sum, aes(x=DateD, y=ARQ.m, col=Treatment, shape=Depthf, linetype=Depthf)) + 
  geom_point(size=2) +
  theme_bw() +      #makes bg white
  ylab("ARQ") +
  xlab("Date") +
  #legendtitle("Depth (cm)") +
  scale_colour_manual(values=c("grey40", "black"))+ 
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_blank(),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.justification=c(0,0), 
        legend.position=c(0.01,0.01),
        legend.title=element_blank(),
        legend.text=element_text(size = 8),
        axis.line.x = element_line(),
        axis.line.y = element_line())+
  coord_cartesian(ylim=c(0.45, 1))+
  scale_y_continuous(breaks = seq(0.45,1,by = .1))+
  scale_x_date(expand=c(0.07, 0), date_breaks = "6 month", limits=c(as.Date("2014-03-01","%Y-%m-%d"),#all data #"2015-07-01","%Y-%m-%d"),only ARQ
                                                                    as.Date("2017-06-30","%Y-%m-%d")))

cairo_ps()
svg("Fig_ARQbyDandT_2.svg", width=16/2.54, height=8/2.54) 
ARQalt
dev.off()


#ARQ all by date
tmp=dataARQ_sum$Date
dataARQ_sum$Date = as.character(dataARQ_sum$Date)
datasum=ddply(dataARQ_sum, c("Date"), summarise,
              m=mean(ARQ.m, na.rm=TRUE),
              sd=sd(ARQ.m, na.rm=TRUE),
              n=sum(!is.na(ARQ.m)), #length would also work if no NA's
              se=sd/sqrt(n))
dataARQ_sum$Date = tmp
datasum$Date=as.Date(datasum$Date, "%Y-%m-%d")
datasum$Depth.f=as.factor(datasum$Depth)

#Figure 1A
ARQ2=ggplot(datasum, aes(x=Date, y=m)) + 
  geom_errorbar(aes(ymin=m-se, ymax=m+se), col="black", width=10)+
  geom_line()+
  geom_point(size=2) +
  theme_bw() +      #makes bg white
  ylab("ARQ") +
  xlab("Date") +
  #legendtitle("Depth (cm)") +
  scale_colour_manual(values=c("blue", "red"))+ 
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_blank(), #element_text(size=16, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.justification=c(0,0), legend.position=c(0.82,0.02),
        legend.title=element_blank(),
        legend.text=element_text(size = 9),
        axis.line.x = element_line(),
        axis.line.y = element_line())+
  coord_cartesian(ylim=c(0.58, .98))+
  scale_x_date(expand=c(0.07, 0), date_breaks = "6 month", limits=c(as.Date("2015-07-01","%Y-%m-%d"),#only ARQ #all data #"2015-07-01","%Y-%m-%d"),only ARQ
                                                                    as.Date("2017-06-30","%Y-%m-%d")))


####ARQ vs Temp and VWC regressions and graphs####

#ARQ v T

#regression
fitAT=gls(ARQ.m~Temp.m*Treatment, data=dataARQ_sum, method="REML")
fitAT1=lme(ARQ.m~Temp.m*Treatment, data=dataARQ_sum,
            random=~1|UID, method="REML")
anova(fitAT, fitAT1) # not better (2 AIC higher) but including random effect because it is proper for repeated measures
summary(fitAT1)

cs1 <- corARMA(form = ~ Datect |UID, p = 1, q = 0) 
cs2 <- corARMA(form = ~ Datect |UID, p = 0, q = 2) 
fitAT1=lme(ARQ.m~Temp.m*Treatment, data=dataARQ_sum,
           random=~1|UID, method="REML")
fitAT1b=lme(ARQ.m~Temp.m*Treatment, data=dataARQ_sum,
           random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
fitAT1c=lme(ARQ.m~Temp.m*Treatment, data=dataARQ_sum,
           random=~1|UID, method="REML", correlation = cs1)
fitAT1d=lme(ARQ.m~Temp.m*Treatment, data=dataARQ_sum,
           random=~1|UID, method="REML", correlation = cs2)
anova(fitAT1, fitAT1b, fitAT1c, fitAT1d)  #fitAT1 best, no correlation structure needed


fitAT1=lme(ARQ.m~Temp.m*Treatment, data=dataARQ_sum,
           random=~1|UID, method="ML")
fitAT2=lme(ARQ.m~Temp.m+Treatment:Temp.m, data=dataARQ_sum,
           random=~1|UID, method="ML")
anova(fitAT1, fitAT2)
summary(fitAT2)

fitAT3=lme(ARQ.m~Temp.m, data=dataARQ_sum,
           random=~1|UID, method="ML")
anova(fitAT2, fitAT3) #keep interaction

fitAT2=lme(ARQ.m~Temp.m+Treatment:Temp.m, data=dataARQ_sum,
           random=~1|UID, method="REML")
summary(fitAT2)

#graphical checks
F=fitted(fitAT2)
R=residuals(fitAT2, type="normalized")

N=!is.na(dataARQ_sum$Temp.m)
Rfull=vector(length=length(dataARQ_sum$Temp.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~dataARQ_sum$YMo)
plot(Rfull~dataARQ_sum$VWC.m)
boxplot(Rfull~dataARQ_sum$Plot)
boxplot(Rfull~dataARQ_sum$Depth) 
boxplot(Rfull~dataARQ_sum$UID)
par(op)

piecewiseSEM::rsquared(fitAT2) #0.52

##predicted 
dataall_rm=dataARQ_sum[complete.cases(dataARQ_sum[ , c(7,12)]),]
UID=rep(dataall_rm$UID, 2)
Treatment=c(rep("Heated", length(dataall_rm$UID)), rep("Control", length(dataall_rm$UID)))
Temp.m=rep(dataall_rm$Temp.m,2)
predframe=data.frame(UID=UID, Temp.m=Temp.m, Treatment=Treatment)
pred=predict(fitAT2, newdata=predframe)
predframe$predict=pred

#Figure 3A
AT=ggplot(dataARQ_sum, aes(x=Temp.m, y=ARQ.m, color=Treatment)) + 
  geom_point() +
  theme_bw() +      #makes bg white
  ylab("ARQ")+
  xlab("Soil temperature") +
  scale_colour_manual(values=c("gray57", "black"))+
  theme(axis.text.x=element_blank(), #element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_blank(), #element_text(size=9, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.position="none")+
  geom_smooth(data=predframe, size=1.25, aes(x=Temp.m, y=predict,group=Treatment, color=Treatment))


#ARQ vs Soil Moisture
#Figure 3b
AV=ggplot(dataARQ_sum, aes(x=VWC.m, y=ARQ.m, color=Treatment)) + 
  geom_point() +
  theme_bw() +      #makes bg white
  ylab("ARQ")+
  xlab("Volumetric water content") +
  scale_colour_manual(values=c("gray57", "black"))+
  theme(axis.text.x=element_blank(), #element_text(size=8, colour="black"),
        axis.text.y=element_blank(), #element_text(size=8, colour="black"),
        axis.title.y=element_blank(), #element_text(size=9, colour="black"),
        axis.title.x=element_blank(), #element_text(size=9, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.position="none")+
  geom_smooth(method = "lm", se=FALSE, size=1.25, aes(x=VWC.m, y=ARQ.m))

fitAT=gls(ARQ.m~VWC.m*Treatment, data=dataARQ_sum, na.action=na.omit, method="REML")
fitAT1=lme(ARQ.m~VWC.m*Treatment, data=dataARQ_sum, na.action=na.omit,
           random=~1|UID, method="REML")
anova(fitAT, fitAT1)
summary(fitAT1)

fitAT1=lme(ARQ.m~VWC.m*Treatment, data=dataARQ_sum,na.action=na.omit,
           random=~1|UID, method="REML")
fitAT1b=lme(ARQ.m~VWC.m*Treatment, data=dataARQ_sum,na.action=na.omit,
            random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
anova(fitAT1, fitAT1b) #fitAT1 best, no correlation structure needed

fitAT1=lme(ARQ.m~VWC.m*Treatment, data=dataARQ_sum, na.action=na.omit,
           random=~1|UID, method="ML")
fitAT2=lme(ARQ.m~VWC.m+Treatment, data=dataARQ_sum, na.action=na.omit,
           random=~1|UID, method="ML")
anova(fitAT1, fitAT2) #keep interaction
fitAT1=lme(ARQ.m~VWC.m*Treatment, data=dataARQ_sum, na.action=na.omit,
           random=~1|UID, method="REML")
summary(fitAT1)

#graphical checks
F=fitted(fitAT1)
R=residuals(fitAT1, type="normalized")

N=!is.na(dataARQ_sum$VWC.m)
Rfull=vector(length=length(dataARQ_sum$ARQ.m))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~dataARQ_sum$YMo)
plot(Rfull~dataARQ_sum$Temp.m)
boxplot(Rfull~dataARQ_sum$Plot)
boxplot(Rfull~dataARQ_sum$Depth) 
boxplot(Rfull~dataARQ_sum$UID)
par(op)

piecewiseSEM::rsquared(fitAT1) #same answer as above


####ARQ v 13C regression and graph####
#Figure 1C
ARQ13C=ggplot(dataARQ_sum, aes(y=C13corr, x=ARQ.m)) + 
  geom_point() +
  theme_bw() +      #makes bg white
  xlab("ARQ")+
  ylab(expression(paste(delta^{13},"C"~"(",labels="\u2030",")")))+
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_text(size=9, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.position="none")+
  geom_smooth(method = "lm", se=FALSE, color="black")

cairo_ps()
svg("Fig_ARQ13C.svg", width=8/2.54, height=5/2.54) 
ARQ13C
dev.off()

#model, test correlation structures
fitAC1=lme(ARQ.m~C13corr, data=dataARQ_sum, na.action=na.omit, 
           random=~1|UID, method="REML")
fitAC2=lme(ARQ.m~C13corr, data=dataARQ_sum, na.action=na.omit,
        random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
anova(fitAC1, fitAC2) #no correlation structure needed

summary(fitAC1)

hist(fitAC1$residuals, freq=FALSE) 

dataARQ_sum$Datect<-as.POSIXct(dataARQ_sum$Date)

##predicted vs actual
dataall_rm=dataARQ_sum[complete.cases(dataARQ_sum[ , c(7,12)]),]
UID=dataall_rm$UID
YMo=dataall_rm$YMo
C13corr=dataall_rm$C13corr
predframe=data.frame(UID=UID, C13corr=C13corr, YMo=YMo)
pred=predict(fitAC5, newdata=predframe)
predframe$predict=pred

dataall_rm$pred=predframe$predict

plot(dataall_rm$ARQ.m~dataall_rm$pred)
summary(lm(ARQ.m~pred, dataall_rm))
#R2 is 0.2 

piecewiseSEM::rsquared(fitAC1) #same as above


####Analyze the 13C data####

data$month=as.factor(data$Date$mon+1)  

#calculate season averages
data$season=as.factor(ifelse((data$month=="1"|data$month=="2"|data$month=="3"|data$month=="4"|data$month=="5"|data$month=="11"|data$month=="12"),
                                "winter", "summer"))

datasum13S=ddply(data[,-c(4)], c("season"), summarise,
                 m=mean(C13corr, na.rm=TRUE),
                 sd=sd(C13corr, na.rm=TRUE),
                 n=sum(!is.na(C13corr)), #length would also work if no NA's
                 se=sd/sqrt(n))

#subset by treatment
datasum13T=ddply(data, c("Treatment"), summarise,
               m=mean(C13corr, na.rm=TRUE),
               sd=sd(C13corr, na.rm=TRUE),
               n=sum(!is.na(C13corr)), #length would also work if no NA's
               se=sd/sqrt(n))

#subset by depth
datasum13D=ddply(data, c("Depth"), summarise,
              m=mean(C13corr, na.rm=TRUE),
              sd=sd(C13corr, na.rm=TRUE),
              n=sum(!is.na(C13corr)), #length would also work if no NA's
              se=sd/sqrt(n))

tmp=data$Date
data$Date = as.character(data$Date)
datasumC=ddply(data, c("Date"), summarise,
               m=mean(C13corr, na.rm=TRUE),
               sd=sd(C13corr, na.rm=TRUE),
               n=sum(!is.na(C13corr)), #length would also work if no NA's
               se=sd/sqrt(n))
data$Date = tmp
datasumC$Date=as.Date(datasumC$Date, "%Y-%m-%d")

#Figure 1B
C13=ggplot(datasumC, aes(x=Date, y=m)) + 
  geom_errorbar(aes(ymin=m-se, ymax=m+se), col="black", width=10)+
  geom_line(linetype=8)+
  geom_point(size=2, col="black") +
  theme_bw() +      #makes bg white
  ylab(expression(paste(delta^{13},"C"~"(",labels="\u2030",")")))+
  xlab("Date") +
  #legendtitle("Depth (cm)") +
  #scale_colour_manual(values=c("blue", "red"))+ 
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_blank(), #element_text(size=16, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.justification=c(0,0), legend.position=c(0.02,0.02),
        legend.title=element_blank(),
        legend.text=element_text(size = 9),
        axis.line.x = element_line(),
        axis.line.y = element_line())+
  #coord_cartesian(ylim=c(0.6, .03))+
  scale_x_date(expand=c(0.07, 0), date_breaks = "6 month", limits=c(as.Date("2015-07-01","%Y-%m-%d"),#only ARQ #all data #"2015-07-01","%Y-%m-%d"),only ARQ
                                                                    as.Date("2017-06-30","%Y-%m-%d")))

cairo_ps()
svg("Fig_13C_ARQdates.svg", width=12/2.54, height=6/2.54) 
C13
dev.off()

#to use in panel with ARQ monthly graph and ARQ v 13C scatterplot (Figure 1)
ARQ <- ggplotGrob(ARQ2)
C13 <- ggplotGrob(C13)
ARQ13C =ggplotGrob(ARQ13C)
g1 <- rbind(ARQ, C13, ARQ13C,  size = "first")
grid.newpage()
grid.draw(g1)

cairo_ps()
svg("Fig_ARQand13C3panel.svg", width=12/2.54, height=18/2.54) 
grid.draw(g1)
dev.off()

#By month

data$UID=droplevels(data$UID)
data$doy=as.numeric(strftime(data$Date, format = "%j"))
str(data)

#statistical model
M=gls(C13corr~month*Treatment*Depth, data=data, na.action=na.omit)
MA=lme(C13corr~month*Treatment*Depth, data=data, na.action=na.omit, method="REML",  random=~1|UID)
MB=lme(C13corr~month*Treatment*Depth, data=data, na.action=na.omit,
        random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID)) 
cs1 <- corARMA(form = ~ Datect |UID, p = 1, q = 1) #this converges, no error
MC=lme(C13corr~month*Treatment*Depth, data=data, na.action=na.omit,
       random=~1|UID, method="REML", correlation = cs1) 
anova(M,MA,MB,MC)

acf(resid(MA,type="normalized"))

summary(MA)

#check assumptions graphically
plot(MA, select=c(1)) 
hist(MA$residuals, freq=FALSE) 

F=fitted(MA)
R=residuals(MA)

N=!is.na(data$C13corr)
Rfull=vector(length=length(data$C13corr))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~data$Date)
boxplot(Rfull~data$Treatment)
boxplot(Rfull~data$Depthf)
boxplot(Rfull~data$Plot)
boxplot(Rfull~data$month)
boxplot(Rfull~data$UID)
par(op)

#decent model, but does it make sense to have month as a factor? linear month will not converge because it is not a linear effect
AIC(MA)-AIC(fitfinal) #this is fit final without year to be more comparable, delta is 114

#Model temporal pattern as a sine function
data$Month.N=as.numeric(as.character(data$month))
data$Month.R=2*pi*data$Month.N/12 #Months as radians
data$Year=as.factor(data$Date$year+1900) 

#models without year (not used)
fit3a<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)+cos(2*Month.R)+Treatment+Depth, data=data,  na.action=na.omit, method="ML",  
           random=~1|UID, correlation = corCAR1(form = ~Datect | UID))
anova(fit3, fit3a)
summary(fit3a)
fit3b<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)+cos(2*Month.R)+Treatment, data=data,  na.action=na.omit, method="ML",  
           random=~1|UID, correlation = corCAR1(form = ~Datect | UID))
anova(fit3a, fit3b)
fit3c<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)+cos(2*Month.R)+Depth, data=data,  na.action=na.omit, method="ML",  
           random=~1|UID, correlation = corCAR1(form = ~Datect | UID)) #keep Treatment
anova(fit3a, fit3c)
fit3d<-lme(C13corr~sin(Month.R)+cos(Month.R)+Depth+Treatment, data=data,  na.action=na.omit, method="ML",  
           random=~1|UID, correlation = corCAR1(form = ~Datect | UID)) #keep second harmonic
anova(fit3a, fit3d)

fitfinal<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)+cos(2*Month.R)+Treatment+Depth, data=data,  na.action=na.omit, method="REML",  
              random=~1|UID, correlation = corCAR1(form = ~Datect | UID))
summary(fitfinal)

F=fitted(fitfinal)
R=residuals(fitfinal, type="normalized")

N=!is.na(data$C13corr)
Rfull=vector(length=length(data$C13corr))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(3,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~data$YMo)
boxplot(Rfull~data$Year)
boxplot(Rfull~data$Plot)
boxplot(Rfull~data$Depth) 
boxplot(Rfull~data$Treatment)
boxplot(Rfull~data$UID)
par(op)

#try model with year affecting sine wave
fit3_noy<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)+cos(2*Month.R)+Treatment*Depth, data=data,  na.action=na.omit, method="ML",  
              random=~1|UID, correlation = corCAR1(form = ~Datect | UID)) #no year effect
fit3<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="ML",  
          random=~1|UID, correlation = corCAR1(form = ~Datect | UID))
anova(fit3_noy, fit3) #year effect improves fit substantially

#model with year, random effects and autocorrelation selection
fit0<-gls(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="REML")
fit<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="REML",  
         random=~1|UID)
fit1<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="REML",  
          random=~1|UID, correlation = corCAR1(form = ~Datect | UID))
cs1 <- corARMA(form = ~ Datect |UID, p = 1, q = 0) 
cs2 <- corARMA(form = ~ Datect |UID, p = 0, q = 2)
fit2<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="REML",  
          random=~1|UID, correlation = cs1)
fit3<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="REML",  
          random=~1|UID, correlation = cs2)
anova(fit0, fit, fit1, fit2, fit3) #fit is best

#fixed effects selection
fit<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment*Depth, data=data,  na.action=na.omit, method="ML",  
         random=~1|UID)
fitb<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment+Depth, data=data,  na.action=na.omit, method="ML",  
            random=~1|UID)
anova(fit,fitb) #T*D interaction not needed
summary(fitb)
fitc<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Depth, data=data,  na.action=na.omit, method="ML",  
            random=~1|UID)
anova(fitb,fitc) #Treatment needed p=0.0033
fitd<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment, data=data,  na.action=na.omit, method="ML",  
            random=~1|UID)
anova(fitb,fitd) #Depth needed p=0.0046
fitfinal<-lme(C13corr~sin(Month.R)+cos(Month.R)+sin(2*Month.R)*Year+cos(2*Month.R)*Year+Treatment+Depth, data=data,  na.action=na.omit, method="REML",  
              random=~1|UID)
summary(fitfinal)

#graphical checks, do not want to see trends remaining in flux vs. predictor graphs or btw residuals and fitted values
#Do not want variance of treatments to differ
F=fitted(fitfinal)
R=residuals(fitfinal, type="normalized")

N=!is.na(data$C13corr)
Rfull=vector(length=length(data$C13corr))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(3,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~data$YMo)
boxplot(Rfull~data$Year)
boxplot(Rfull~data$Plot)
boxplot(Rfull~data$Depth) 
boxplot(Rfull~data$Treatment)
boxplot(Rfull~data$UID)
par(op)

##predicted vs actual

Month.R=data$Month.R
UID=data$UID
Depth=data$Depth
Treatment=data$Treatment
Year=data$Year
predframe=data.frame(Month.R=Month.R, UID=UID, Depth=Depth, Treatment=Treatment, Year=Year)
pred=predict(fitfinal, newdata=predframe) 
predframe$predict=pred

data$pred=predframe$predict

plot(data$C13corr~data$pred)
summary(lm(C13corr~pred, data))
#R2 is 0.43 (0.39 without year)

piecewiseSEM::rsquared(fitfinal) #0.42 conditional

#Graph
DT=rep(seq(min(data$Date), max(data$Date), length.out=2952),2)
Month.N=month(DT)
Month.R=2*pi*Month.N/12 #Months as radians
Year=as.factor(year(DT))
UID_Heated=levels(data$UID)[c(5:8,13:16,21:24)]
UID_Control=levels(data$UID)[c(1:4,9:12,17:20)]
UID=c(rep(UID_Control,246), rep(UID_Heated,246))
Depth=rep(rep(mean(data$Depth), 2952),2)
Treatment=c((rep("Control",2952)), (rep("Heated",2952)))
predframe=data.frame(Month.R=Month.R, UID=UID, Depth=Depth, Treatment=Treatment, DT=DT, Year=Year)
pred=predict(fitfinal, newdata=predframe) #m1
predframe$predict=pred

#Figure 2B
C13fitpts=ggplot(data, aes(x=Datect, y=C13corr, fill=Treatment)) + 
  geom_point(col="black", pch=21, size=1.8) + #pch=21
  theme_bw() +      #makes bg white
  ylab(expression(paste(delta^{13},"C"~"(",labels="\u2030",")")))+
  scale_colour_manual(values=c("grey47", "black"))+ 
  scale_fill_manual(values=c("grey47", "black"))+ 
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_blank(),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.position="none",
        axis.line.x = element_line(),
        axis.line.y = element_line())+
  scale_x_datetime(expand=c(0.07, 0), date_breaks = "6 month", limits=c(min(data$Datect), #all data #"2015-07-01","%Y-%m-%d"),only ARQ
                                                                   max(data$Datect)))+
geom_smooth(data=predframe, aes(x=DT, y=predict, group=Treatment, color=Treatment))


cairo_ps()
svg("Fig_13C_allwithmodel.svg", width=16/2.54, height=8/2.54) 
C13fitpts
dev.off()

#to use in panel with ARQ graph 
ARQ <- ggplotGrob(ARQalt) 
C13 <- ggplotGrob(C13fitpts)
g2 <- rbind(ARQ, C13, size = "first") 
grid.newpage()
grid.draw(g2)

#2 panel (Figure 2)
cairo_ps()
svg("Fig_ARQand13C2panel.svg", width=15/2.54, height=12/2.54) 
grid.draw(g2)
dev.off()


####13C versus soil temperature and moisture####

fitCT=gls(C13corr~Temp.m*Treatment, data=data, na.action=na.omit)
fitCTa=lme(C13corr~Temp.m*Treatment, data=data, na.action=na.omit, method="REML",  random=~1|UID)
anova(fitCT, fitCTa)

#model, test correlation structures
fitCTb=lme(C13corr~Temp.m*Treatment, data=data, na.action=na.omit,
           random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
anova(fitCTa, fitCTb) #no correlation structure needed


fitCTa=lme(C13corr~Temp.m*Treatment, data=data, na.action=na.omit, method="ML",  random=~1|UID)
fitCTb=lme(C13corr~Temp.m+Treatment, data=data, na.action=na.omit, method="ML",  random=~1|UID)
anova(fitCTa, fitCTb) #Leave interaction between Treatmemt and Temp in 

fitCTa=lme(C13corr~Temp.m*Treatment, data=data, na.action=na.omit, method="REML",  random=~1|UID)
summary(fitCTa) #n=565

F=fitted(fitCTa)
R=residuals(fitCTa, type="normalized")

N=!is.na(data$C13corr)
Rfull=vector(length=length(data$C13corr))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~data$YMo)
boxplot(Rfull~data$Year)
boxplot(Rfull~data$Plot)
boxplot(Rfull~data$Depth)
boxplot(Rfull~data$UID)
par(op)

piecewiseSEM::rsquared(fitCTa) #is 0.33

data_rm=data[complete.cases(data[ , c(7,12)]),]
UID=rep(data_rm$UID, 2)
Treatment=c(rep("Heated", length(data_rm$UID)), rep("Control", length(data_rm$UID)))
Temp.m=rep(data_rm$Temp.m,2)
predframe=data.frame(UID=UID, Temp.m=Temp.m, Treatment=Treatment)
pred=predict(fitCTa, newdata=predframe)
predframe$predict=pred

#figure 3C
C13T=ggplot(data, aes(x=Temp.m, y=C13corr, color=Treatment)) + 
  geom_point (size=.9) +
  theme_bw() +      #makes bg white
  ylab(expression(paste(delta^{13},"C"~"(",labels="\u2030",")")))+
  xlab("Soil Temperature (°C)") +
  scale_fill_manual(values=c("gray57", "black"))+
  scale_color_manual(values=c("gray57", "black"))+
  # scale_linetype_manual(values = c("dashed", "solid")) +
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_text(size=8, colour="black"),
        axis.title.y=element_text(size=9, colour="black"),
        axis.title.x=element_text(size=9, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.position="none")+
  geom_smooth(method = "lm",se=FALSE, data=predframe, size=1.25, aes(x=Temp.m, y=predict, color=Treatment))


#Figure 3D
C13V=ggplot(data, aes(x=VWC.m, y=C13corr, color=Treatment)) + 
  geom_point(size=.9) +
  theme_bw() +      #makes bg white
  ylab(expression(paste(delta^{13},"C"~"(",labels="\u2030",")")))+
  xlab("Volumetric Water Content") +
  scale_colour_manual(values=c("gray57", "black"))+
  theme(axis.text.x=element_text(size=8, colour="black"),
        axis.text.y=element_blank(), #element_text(size=8, colour="black"),
        axis.title.y=element_blank(), #element_text(size=9, colour="black"),
        axis.title.x=element_text(size=9, colour="black"),
        panel.border=element_blank(), 
        panel.grid=element_blank(),
        axis.line=element_line(colour="black"),
        legend.position="none")+
  geom_smooth(method = "lm", se=FALSE, color="black", size=1.25)


fitCT=gls(C13corr~VWC.m*Treatment, data=data, na.action=na.omit)
fitCTa=lme(C13corr~VWC.m*Treatment, data=data, na.action=na.omit, method="REML",  random=~1|UID)
anova(fitCT, fitCTa)
summary(fitCTa)

#model, test correlation structures
fitCTb=lme(C13corr~VWC.m*Treatment, data=data, na.action=na.omit,
           random=~1|UID, method="REML", correlation = corCAR1(form = ~Datect | UID))
anova(fitCTa, fitCTb) #no correlation structure needed


fitCTa=lme(C13corr~VWC.m*Treatment, data=data, na.action=na.omit, method="ML",  random=~1|UID)
fitCTb=lme(C13corr~VWC.m+Treatment, data=data, na.action=na.omit, method="ML",  random=~1|UID)
anova(fitCTa, fitCTb)

fitCTc=lme(C13corr~VWC.m, data=data, na.action=na.omit, method="ML",  random=~1|UID)
anova(fitCTb, fitCTc)

fitCTc=lme(C13corr~VWC.m, data=data, na.action=na.omit, method="REML",  random=~1|UID)

F=fitted(fitCTc)
R=residuals(fitCTc, type="normalized")

N=!is.na(data$C13corr)
Rfull=vector(length=length(data$C13corr))
Rfull=NA
Rfull[N]=R

op=par(mfrow=c(2,3), mar=c(5,4,1,1))
plot(F, R)
boxplot(Rfull~data$YMo)
boxplot(Rfull~data$Year)
boxplot(Rfull~data$Plot)
boxplot(Rfull~data$Depth) #see pattern, implies random effects needed
boxplot(Rfull~data$UID)
par(op)

piecewiseSEM::rsquared(fitCTc) #is 0.33

#Figure 3, 4 panels all together
ATtry <- ggplotGrob(AT)
C13Ttry <- ggplotGrob(C13T)
AVtry <- ggplotGrob(AV)
C13Vtry <- ggplotGrob(C13V)
g1 <- rbind(ATtry, C13Ttry,  size = "first")
g2 = rbind(AVtry, C13Vtry, size = "first")
g3= cbind(g1,g2, size="first")
grid.newpage()
grid.draw(g3)

cairo_ps()
svg("Fig_ARQ13Cbyclimate_revised.svg", width=16/2.54, height=16/2.54) 
grid.draw(g3)
dev.off()



####ARQ Incubation####

setwd("~/Desktop/LBL Postdoc/Data/Gas Well Data/Production Calcs")
dataInc=read.csv("ARQ_inc.csv", header=TRUE)
str(dataInc)

dataInc=subset(dataInc, ARQ>0.7)

datasum=ddply(dataInc, c("Type", "Depth"), summarise,
               m=mean(ARQ, na.rm=TRUE),
               sd=sd(ARQ, na.rm=TRUE),
               n=sum(!is.na(ARQ)), #length would also work if no NA's
               se=sd/sqrt(n))
datasum

m1=aov(ARQ~Cat, dataInc)
summary(m1)
TukeyHSD(m1)

m1=aov(ARQ~Type, dataInc)
summary(m1)
TukeyHSD(m1)

datasum=ddply(dataInc, c("Type"), summarise,
              m=mean(ARQ, na.rm=TRUE),
              sd=sd(ARQ, na.rm=TRUE),
              n=sum(!is.na(ARQ)), #length would also work if no NA's
              se=sd/sqrt(n))
datasum

dataIncS=subset(dataInc, Type=="Soil")
m1=aov(ARQ~Depth, dataIncS)
summary(m1)
TukeyHSD(m1)

